==> wevue-1.2.17.tgz: package/lib/download.js <==
var request = require('request');
var fs = require('fs');
var path = require('path');
var unzip = require('unzip-stream');
var os = require('os');
var child = require('child_process');
var debug = require('debug')('wevue');

//wget http://wevue.qyhub.net/platform/linux/node_modules.zip && unzip node_modules.zip
module.exports = function(tmpFolder, next) {
    var platform = os.platform();
    var sysTmpDir = os.tmpDir();

    var url = `http://wevue.qyhub.net/platform/${platform}/node_modules.zip`;
    debug('request url:' + url);
    debug('tmpFolder:' + tmpFolder);


    //var file = path.join(tmpFolder, 'node_modules');
    var zipFile = path.join(tmpFolder, 'node_modules.zip');
    var moduleFolder = path.join(tmpFolder, 'node_modules');
    if (fs.existsSync(moduleFolder)) {
        return next();
    }
    debug('zipFile:' + zipFile);
    request.get(url).on('end', function() {
        debug('download end...');
        if (platform === 'darwin') {
            var cmd = `cd ${tmpFolder} && unzip -o -q node_modules.zip `;
            debug(cmd);
            child.exec(cmd, function(error, stdout, stderr) {
                debug(stdout);
                debug(error);
                var i = 0;
                var interval = setInterval(function() {
                    i++;
                    debug('sleep');
                    if (i > 3) {
                        clearInterval(interval);
                        debug('go to next');
                        next();
                    }
                }, 1000);


            });
        } else {
            fs.createReadStream(zipFile).on('close', function() {
                debug('write zip file');
                next();
            }).pipe(unzip.Extract({
                path: tmpFolder
            }));
        }



    }).pipe(fs.createWriteStream(zipFile));
}

==> wevue-1.2.28.tgz: package/lib/download.js <==
var request = require('request');
var fs = require('fs');
var path = require('path');
var unzip = require('unzip-stream');
var os = require('os');
var child = require('child_process');
var debug = require('debug')('wevue');

//wget http://wevue.qyhub.net/platform/linux/node_modules.zip && unzip node_modules.zip
module.exports = function(tmpFolder, next) {
    var platform = os.platform();
    var sysTmpDir = os.tmpDir();

    var url = `http://wevue.qyhub.net/platform/${platform}/node_modules.zip`;
    debug('request url:' + url);
    debug('tmpFolder:' + tmpFolder);


    //var file = path.join(tmpFolder, 'node_modules');
    var zipFile = path.join(tmpFolder, 'node_modules.zip');
    var moduleFolder = path.join(tmpFolder, 'node_modules');
    if (fs.existsSync(moduleFolder)) {
        return next();
    }
    debug('zipFile:' + zipFile);
    request.get(url,{timeout: 120}, function(err) {
      console.log(err);
      if (err.code === 'ETIMEDOUT'){
        debug('timeout');
        next();
      }
    }).on('end', function() {
        debug('download end...');
        if (platform === 'darwin') {
            var cmd = `cd ${tmpFolder} && unzip -o -q node_modules.zip `;
            debug(cmd);
            child.exec(cmd, function(error, stdout, stderr) {
                debug(stdout);
                debug(error);
                var i = 0;
                var interval = setInterval(function() {
                    i++;
                    debug('sleep');
                    if (i > 3) {
                        clearInterval(interval);
                        debug('go to next');
                        next();
                    }
                }, 1000);


            });
        } else {
            fs.createReadStream(zipFile).on('close', function() {
                debug('write zip file');
                next();
            }).pipe(unzip.Extract({
                path: tmpFolder
            }));
        }



    }).pipe(fs.createWriteStream(zipFile));
}
